PolymarketDataClientConfigBuilder

Struct PolymarketDataClientConfigBuilder 

pub struct PolymarketDataClientConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> PolymarketDataClientConfigBuilder<S>

pub fn build(self) -> PolymarketDataClientConfig
where S: IsComplete,

Finish building and return the requested object

pub fn base_url_http( self, value: String, ) -> PolymarketDataClientConfigBuilder<SetBaseUrlHttp<S>>
where S::BaseUrlHttp: IsUnset,

Optional (Some / Option setters).

pub fn maybe_base_url_http( self, value: Option<String>, ) -> PolymarketDataClientConfigBuilder<SetBaseUrlHttp<S>>
where S::BaseUrlHttp: IsUnset,

Optional (Some / Option setters).

pub fn base_url_ws( self, value: String, ) -> PolymarketDataClientConfigBuilder<SetBaseUrlWs<S>>
where S::BaseUrlWs: IsUnset,

Optional (Some / Option setters).

pub fn maybe_base_url_ws( self, value: Option<String>, ) -> PolymarketDataClientConfigBuilder<SetBaseUrlWs<S>>
where S::BaseUrlWs: IsUnset,

Optional (Some / Option setters).

pub fn base_url_gamma( self, value: String, ) -> PolymarketDataClientConfigBuilder<SetBaseUrlGamma<S>>
where S::BaseUrlGamma: IsUnset,

Optional (Some / Option setters).

pub fn maybe_base_url_gamma( self, value: Option<String>, ) -> PolymarketDataClientConfigBuilder<SetBaseUrlGamma<S>>
where S::BaseUrlGamma: IsUnset,

Optional (Some / Option setters).

pub fn base_url_data_api( self, value: String, ) -> PolymarketDataClientConfigBuilder<SetBaseUrlDataApi<S>>
where S::BaseUrlDataApi: IsUnset,

Optional (Some / Option setters).

pub fn maybe_base_url_data_api( self, value: Option<String>, ) -> PolymarketDataClientConfigBuilder<SetBaseUrlDataApi<S>>
where S::BaseUrlDataApi: IsUnset,

Optional (Some / Option setters).

pub fn http_timeout_secs( self, value: u64, ) -> PolymarketDataClientConfigBuilder<SetHttpTimeoutSecs<S>>
where S::HttpTimeoutSecs: IsUnset,

Optional (Some / Option setters). Default: 60.

HTTP timeout in seconds.

pub fn maybe_http_timeout_secs( self, value: Option<u64>, ) -> PolymarketDataClientConfigBuilder<SetHttpTimeoutSecs<S>>
where S::HttpTimeoutSecs: IsUnset,

Optional (Some / Option setters). Default: 60.

HTTP timeout in seconds.

pub fn ws_timeout_secs( self, value: u64, ) -> PolymarketDataClientConfigBuilder<SetWsTimeoutSecs<S>>
where S::WsTimeoutSecs: IsUnset,

Optional (Some / Option setters). Default: 30.

WebSocket timeout in seconds.

pub fn maybe_ws_timeout_secs( self, value: Option<u64>, ) -> PolymarketDataClientConfigBuilder<SetWsTimeoutSecs<S>>
where S::WsTimeoutSecs: IsUnset,

Optional (Some / Option setters). Default: 30.

WebSocket timeout in seconds.

pub fn ws_max_subscriptions( self, value: usize, ) -> PolymarketDataClientConfigBuilder<SetWsMaxSubscriptions<S>>
where S::WsMaxSubscriptions: IsUnset,

Optional (Some / Option setters). Default: crate::common::consts::WS_DEFAULT_SUBSCRIPTIONS.

pub fn maybe_ws_max_subscriptions( self, value: Option<usize>, ) -> PolymarketDataClientConfigBuilder<SetWsMaxSubscriptions<S>>
where S::WsMaxSubscriptions: IsUnset,

Optional (Some / Option setters). Default: crate::common::consts::WS_DEFAULT_SUBSCRIPTIONS.

pub fn update_instruments_interval_mins( self, value: u64, ) -> PolymarketDataClientConfigBuilder<SetUpdateInstrumentsIntervalMins<S>>
where S::UpdateInstrumentsIntervalMins: IsUnset,

Optional (Some / Option setters). Default: 60.

Instrument reload interval in minutes.

pub fn maybe_update_instruments_interval_mins( self, value: Option<u64>, ) -> PolymarketDataClientConfigBuilder<SetUpdateInstrumentsIntervalMins<S>>
where S::UpdateInstrumentsIntervalMins: IsUnset,

Optional (Some / Option setters). Default: 60.

Instrument reload interval in minutes.

pub fn subscribe_new_markets( self, value: bool, ) -> PolymarketDataClientConfigBuilder<SetSubscribeNewMarkets<S>>
where S::SubscribeNewMarkets: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to new market discovery events via WebSocket.

pub fn maybe_subscribe_new_markets( self, value: Option<bool>, ) -> PolymarketDataClientConfigBuilder<SetSubscribeNewMarkets<S>>
where S::SubscribeNewMarkets: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to subscribe to new market discovery events via WebSocket.

pub fn auto_load_missing_instruments( self, value: bool, ) -> PolymarketDataClientConfigBuilder<SetAutoLoadMissingInstruments<S>>
where S::AutoLoadMissingInstruments: IsUnset,

Optional (Some / Option setters). Default: true.

Whether subscribe and request commands referencing an unknown instrument should trigger an ad-hoc load via the instrument provider. Concurrent misses within auto_load_debounce_ms are coalesced into a single batched request.

pub fn maybe_auto_load_missing_instruments( self, value: Option<bool>, ) -> PolymarketDataClientConfigBuilder<SetAutoLoadMissingInstruments<S>>
where S::AutoLoadMissingInstruments: IsUnset,

Optional (Some / Option setters). Default: true.

Whether subscribe and request commands referencing an unknown instrument should trigger an ad-hoc load via the instrument provider. Concurrent misses within auto_load_debounce_ms are coalesced into a single batched request.

pub fn auto_load_debounce_ms( self, value: u64, ) -> PolymarketDataClientConfigBuilder<SetAutoLoadDebounceMs<S>>
where S::AutoLoadDebounceMs: IsUnset,

Optional (Some / Option setters). Default: 100.

The window (milliseconds) over which concurrent auto-load requests are batched.

pub fn maybe_auto_load_debounce_ms( self, value: Option<u64>, ) -> PolymarketDataClientConfigBuilder<SetAutoLoadDebounceMs<S>>
where S::AutoLoadDebounceMs: IsUnset,

Optional (Some / Option setters). Default: 100.

The window (milliseconds) over which concurrent auto-load requests are batched.

pub fn filters( self, value: Vec<Arc<dyn InstrumentFilter>>, ) -> PolymarketDataClientConfigBuilder<SetFilters<S>>
where S::Filters: IsUnset,

Optional (Some / Option setters). Default: <Vec<Arc<dyn InstrumentFilter>> as Default>::default().

Instrument filters applied to all instruments during loading and discovery.

pub fn maybe_filters( self, value: Option<Vec<Arc<dyn InstrumentFilter>>>, ) -> PolymarketDataClientConfigBuilder<SetFilters<S>>
where S::Filters: IsUnset,

Optional (Some / Option setters). Default: <Vec<Arc<dyn InstrumentFilter>> as Default>::default().

Instrument filters applied to all instruments during loading and discovery.

pub fn new_market_filter( self, value: Arc<dyn InstrumentFilter>, ) -> PolymarketDataClientConfigBuilder<SetNewMarketFilter<S>>
where S::NewMarketFilter: IsUnset,

Optional (Some / Option setters). Optional filter applied to newly discovered markets before instrument emission.

pub fn maybe_new_market_filter( self, value: Option<Arc<dyn InstrumentFilter>>, ) -> PolymarketDataClientConfigBuilder<SetNewMarketFilter<S>>
where S::NewMarketFilter: IsUnset,

Optional (Some / Option setters). Optional filter applied to newly discovered markets before instrument emission.

pub fn transport_backend( self, value: TransportBackend, ) -> PolymarketDataClientConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).

pub fn maybe_transport_backend( self, value: Option<TransportBackend>, ) -> PolymarketDataClientConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).