PolymarketExecutionClientConfig

Struct PolymarketExecutionClientConfig 

pub struct PolymarketExecutionClientConfig {
Show 18 fields pub account_id: AccountId, pub private_key: Option<String>, pub api_key: Option<String>, pub api_secret: Option<String>, pub passphrase: Option<String>, pub funder: Option<String>, pub signature_type: SignatureType, pub base_url_http: Option<String>, pub base_url_ws: Option<String>, pub base_url_data_api: Option<String>, pub proxy_url: Option<String>, pub http_timeout_secs: u64, pub max_retries: u32, pub retry_delay_initial_ms: u64, pub retry_delay_max_ms: u64, pub heartbeat_enabled: bool, pub transport_backend: TransportBackend, pub instrument_config: Option<PolymarketInstrumentProviderConfig>,
}
Configuration for the Polymarket execution client.

Debug is implemented manually to redact secrets, so it is not part of the derive list.

Fields

account_id: AccountIdprivate_key: Option<String>

Falls back to POLYMARKET_PK env var.

api_key: Option<String>

Falls back to POLYMARKET_API_KEY env var.

api_secret: Option<String>

Falls back to POLYMARKET_API_SECRET env var.

passphrase: Option<String>

Falls back to POLYMARKET_PASSPHRASE env var.

funder: Option<String>

Falls back to POLYMARKET_FUNDER env var.

signature_type: SignatureTypebase_url_http: Option<String>base_url_ws: Option<String>base_url_data_api: Option<String>proxy_url: Option<String>

Optional HTTP or HTTPS proxy URL for all HTTP and WebSocket transports.

http_timeout_secs: u64max_retries: u32retry_delay_initial_ms: u64retry_delay_max_ms: u64heartbeat_enabled: bool

Enables authenticated order-safety heartbeats.

transport_backend: TransportBackend

WebSocket transport backend (defaults to Sockudo).

instrument_config: Option<PolymarketInstrumentProviderConfig>

Same instrument provider configuration used by the data client.

Reconciliation classifies unmapped records from load_ids on this config. When that set is non-empty, venue records for other instruments are out of scope. When this field is unset, or load_ids is unset or empty, every record is in scope.

Implementations

Source

impl PolymarketExecutionClientConfig

pub fn builder() -> PolymarketExecutionClientConfigBuilder

Create an instance of PolymarketExecutionClientConfig using the builder syntax

Source

impl PolymarketExecutionClientConfig

pub fn new() -> Self

pub fn validated_proxy_url(&self) -> Result<Option<ProxyUrl>, TransportError>

Returns the validated proxy URL, if configured.

Errors

Returns an error when the URL is malformed, has no host, or does not use HTTP or HTTPS.

pub const fn has_proxy_url(&self) -> bool

pub fn has_credentials(&self) -> bool

pub fn reconciliation_load_ids(&self) -> Option<&[InstrumentId]>

Returns provider load_ids used to classify unmapped reconciliation records.

pub fn http_url(&self) -> String

pub fn ws_url(&self) -> String

pub fn data_api_url(&self) -> String