PolymarketInstrumentProviderConfigBuilder

Struct PolymarketInstrumentProviderConfigBuilder 

pub struct PolymarketInstrumentProviderConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> PolymarketInstrumentProviderConfigBuilder<S>

pub fn build(self) -> PolymarketInstrumentProviderConfig
where S: IsComplete,

Finish building and return the requested object

pub fn load_all( self, value: bool, ) -> PolymarketInstrumentProviderConfigBuilder<SetLoadAll<S>>
where S::LoadAll: IsUnset,

Optional (Some / Option setters). Default: false.

Whether all venue instruments should be loaded on startup.

pub fn maybe_load_all( self, value: Option<bool>, ) -> PolymarketInstrumentProviderConfigBuilder<SetLoadAll<S>>
where S::LoadAll: IsUnset,

Optional (Some / Option setters). Default: false.

Whether all venue instruments should be loaded on startup.

pub fn load_ids( self, value: Vec<InstrumentId>, ) -> PolymarketInstrumentProviderConfigBuilder<SetLoadIds<S>>
where S::LoadIds: IsUnset,

Optional (Some / Option setters). Optional instrument IDs to load on startup instead of a full bootstrap.

pub fn maybe_load_ids( self, value: Option<Vec<InstrumentId>>, ) -> PolymarketInstrumentProviderConfigBuilder<SetLoadIds<S>>
where S::LoadIds: IsUnset,

Optional (Some / Option setters). Optional instrument IDs to load on startup instead of a full bootstrap.

pub fn filters( self, value: HashMap<String, String>, ) -> PolymarketInstrumentProviderConfigBuilder<SetFilters<S>>
where S::Filters: IsUnset,

Optional (Some / Option setters). Optional Gamma-style query filters encoded as string key/value pairs.

pub fn maybe_filters( self, value: Option<HashMap<String, String>>, ) -> PolymarketInstrumentProviderConfigBuilder<SetFilters<S>>
where S::Filters: IsUnset,

Optional (Some / Option setters). Optional Gamma-style query filters encoded as string key/value pairs.

pub fn event_slugs( self, value: Vec<String>, ) -> PolymarketInstrumentProviderConfigBuilder<SetEventSlugs<S>>
where S::EventSlugs: IsUnset,

Optional (Some / Option setters). Optional static event slugs to resolve to markets during bootstrap.

pub fn maybe_event_slugs( self, value: Option<Vec<String>>, ) -> PolymarketInstrumentProviderConfigBuilder<SetEventSlugs<S>>
where S::EventSlugs: IsUnset,

Optional (Some / Option setters). Optional static event slugs to resolve to markets during bootstrap.

pub fn market_slugs( self, value: Vec<String>, ) -> PolymarketInstrumentProviderConfigBuilder<SetMarketSlugs<S>>
where S::MarketSlugs: IsUnset,

Optional (Some / Option setters). Optional static market slugs to load directly during bootstrap.

pub fn maybe_market_slugs( self, value: Option<Vec<String>>, ) -> PolymarketInstrumentProviderConfigBuilder<SetMarketSlugs<S>>
where S::MarketSlugs: IsUnset,

Optional (Some / Option setters). Optional static market slugs to load directly during bootstrap.

pub fn event_slug_builder( self, value: PolymarketUpDownEventSlugConfig, ) -> PolymarketInstrumentProviderConfigBuilder<SetEventSlugBuilder<S>>
where S::EventSlugBuilder: IsUnset,

Optional (Some / Option setters). Optional Rust-backed Up/Down event slug builder.

pub fn maybe_event_slug_builder( self, value: Option<PolymarketUpDownEventSlugConfig>, ) -> PolymarketInstrumentProviderConfigBuilder<SetEventSlugBuilder<S>>
where S::EventSlugBuilder: IsUnset,

Optional (Some / Option setters). Optional Rust-backed Up/Down event slug builder.

pub fn log_warnings( self, value: bool, ) -> PolymarketInstrumentProviderConfigBuilder<SetLogWarnings<S>>
where S::LogWarnings: IsUnset,

Optional (Some / Option setters). Default: true.

Whether provider warnings should be logged.

pub fn maybe_log_warnings( self, value: Option<bool>, ) -> PolymarketInstrumentProviderConfigBuilder<SetLogWarnings<S>>
where S::LogWarnings: IsUnset,

Optional (Some / Option setters). Default: true.

Whether provider warnings should be logged.

pub fn use_gamma_markets( self, value: bool, ) -> PolymarketInstrumentProviderConfigBuilder<SetUseGammaMarkets<S>>
where S::UseGammaMarkets: IsUnset,

Optional (Some / Option setters). Default: false.

Compatibility field matching the Python adapter. The Rust provider already uses the Gamma API for bootstrap, so this currently has no behavioral effect beyond configuration parity.

pub fn maybe_use_gamma_markets( self, value: Option<bool>, ) -> PolymarketInstrumentProviderConfigBuilder<SetUseGammaMarkets<S>>
where S::UseGammaMarkets: IsUnset,

Optional (Some / Option setters). Default: false.

Compatibility field matching the Python adapter. The Rust provider already uses the Gamma API for bootstrap, so this currently has no behavioral effect beyond configuration parity.