pub struct PolymarketDataClientConfig {Show 14 fields
pub base_url_http: Option<String>,
pub base_url_ws: Option<String>,
pub base_url_gamma: Option<String>,
pub base_url_data_api: Option<String>,
pub http_timeout_secs: u64,
pub ws_timeout_secs: u64,
pub ws_max_subscriptions: usize,
pub update_instruments_interval_mins: u64,
pub subscribe_new_markets: bool,
pub auto_load_missing_instruments: bool,
pub auto_load_debounce_ms: u64,
pub filters: Vec<Arc<dyn InstrumentFilter>>,
pub new_market_filter: Option<Arc<dyn InstrumentFilter>>,
pub transport_backend: TransportBackend,
}Expand description
Configuration for the Polymarket data client.
Fields
base_url_http: Option<String>base_url_ws: Option<String>base_url_gamma: Option<String>base_url_data_api: Option<String>http_timeout_secs: u64HTTP timeout in seconds.
ws_timeout_secs: u64WebSocket timeout in seconds.
ws_max_subscriptions: usizeupdate_instruments_interval_mins: u64Instrument reload interval in minutes.
subscribe_new_markets: boolWhether to subscribe to new market discovery events via WebSocket.
auto_load_missing_instruments: boolWhether subscribe and request commands referencing an unknown instrument should
trigger an ad-hoc load via the instrument provider. Concurrent misses within
auto_load_debounce_ms are coalesced into a single batched request.
auto_load_debounce_ms: u64The window (milliseconds) over which concurrent auto-load requests are batched.
filters: Vec<Arc<dyn InstrumentFilter>>Instrument filters applied to all instruments during loading and discovery.
new_market_filter: Option<Arc<dyn InstrumentFilter>>Optional filter applied to newly discovered markets before instrument emission.
transport_backend: TransportBackendWebSocket transport backend (defaults to Tungstenite).
Implementations
Sourceimpl PolymarketDataClientConfig
impl PolymarketDataClientConfig
Sourcepub fn builder() -> PolymarketDataClientConfigBuilder
pub fn builder() -> PolymarketDataClientConfigBuilder
Create an instance of PolymarketDataClientConfig using the builder syntax